-- |
-- Module      : Network.TLS.Extra.Compression
-- License     : BSD-style
-- Maintainer  : Vincent Hanquez <vincent@snarc.org>
-- Stability   : experimental
-- Portability : unknown
--
module Network.TLS.Extra.Compression
    (
    ) where

--import Network.TLS.Compression
